Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Event ¶
type Event struct {
// This string should indicate the type of event, 'email', 'dropped file' etc.
Type string `json:"type"`
// A time stamp of the time the event happened
Timestamp time.Time `json:"timestamp"`
// An array of samples, (attachments, the file dropped etc).
Samples []Sample `json:"samples"`
// The source of the event, (name of the plugin that generated the event, unenforced)
Source string `json:"source"`
// Any metadata about the event, an array of tags or a more complicated map detailing
// the botnet it came from etc etc
Metadata Metadata `json:"metadata"`
}
The type that is used to represent events passed through the sinkhole.
type Metadata ¶
type Metadata interface{}
Metadata is defined as an interface{} so that we can use any method for attaching metadata to an event. For example, an array of string tags or a more complicated map of data.
Click to show internal directories.
Click to hide internal directories.